All Modules
```````````

.. toctree:: :maxdepth: 1

  zhmc_adapter - Manages an adapter in a CPC. <zhmc_adapter_module>
  zhmc_cpc - Manages a CPC. <zhmc_cpc_module>
  zhmc_crypto_attachment - Manages the attachment of crypto adapters and domains to partitions. <zhmc_crypto_attachment_module>
  zhmc_hba - Manages HBAs in existing partitions (without "dpm-storage-management" feature) <zhmc_hba_module>
  zhmc_nic - Manages NICs in existing partitions <zhmc_nic_module>
  zhmc_partition - Manages partitions <zhmc_partition_module>
  zhmc_storage_group - Manages DPM storage groups (with "dpm-storage-management" feature) <zhmc_storage_group_module>
  zhmc_storage_group_attachment - Manages the attachment of DPM storage groups to partitions (with "dpm-storage-management" feature) <zhmc_storage_group_attachment_module>
  zhmc_storage_volume - Manages DPM storage volumes in existing storage groups (with "dpm-storage-management" feature) <zhmc_storage_volume_module>
  zhmc_virtual_function - Manages virtual functions in existing partitions <zhmc_virtual_function_module>



.. note::
    -  (D): This marks a module as deprecated, which means a module is kept for backwards compatibility but usage is discouraged.
       The module documentation details page may explain more about this rationale.
